# Supported AWS services

## What is session

Session is `boto34.boto3.Session` for [boto3](https://pypi.org/project/boto3/),
`boto34.aioboto3.Session` for [aioboto3](https://pypi.org/project/aioboto3/),
or `boto34.aiobotocore.Session` for [aiobotocore](https://pypi.org/project/aiobotocore/).

You can use any service with any backend. Service availability depends on your [botocore](https://pypi.org/project/botocore/) version.

Currently there are 402 supported services.

## List of supported AWS services

| Service name | Type annotated | Usage | boto3 equivalent |
|-|-|-|-|
| [AccessAnalyzer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#accessanalyzer) | ✓ | `session.accessanalyzer.client(...)` | `boto3.client("accessanalyzer", ...)` |
| [Account](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#account) | ✓ | `session.account.client(...)` | `boto3.client("account", ...)` |
| [ACM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/acm.html#acm) | ✓ | `session.acm.client(...)` | `boto3.client("acm", ...)` |
| [ACMPCA](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/acm-pca.html#acmpca) | ✓ | `session.acm_pca.client(...)` | `boto3.client("acm-pca", ...)` |
| [PrometheusService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#prometheusservice) | ✓ | `session.amp.client(...)` | `boto3.client("amp", ...)` |
| [Amplify](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplify.html#amplify) | ✓ | `session.amplify.client(...)` | `boto3.client("amplify", ...)` |
| [AmplifyBackend](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifybackend.html#amplifybackend) | ✓ | `session.amplifybackend.client(...)` | `boto3.client("amplifybackend", ...)` |
| [AmplifyUIBuilder](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amplifyuibuilder.html#amplifyuibuilder) | ✓ | `session.amplifyuibuilder.client(...)` | `boto3.client("amplifyuibuilder", ...)` |
| [APIGateway](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/apigateway.html#apigateway) | ✓ | `session.apigateway.client(...)` | `boto3.client("apigateway", ...)` |
| [ApiGatewayManagementApi](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/apigatewaymanagementapi.html#apigatewaymanagementapi) | ✓ | `session.apigatewaymanagementapi.client(...)` | `boto3.client("apigatewaymanagementapi", ...)` |
| [ApiGatewayV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/apigatewayv2.html#apigatewayv2) | ✓ | `session.apigatewayv2.client(...)` | `boto3.client("apigatewayv2", ...)` |
| [AppConfig](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appconfig.html#appconfig) | ✓ | `session.appconfig.client(...)` | `boto3.client("appconfig", ...)` |
| [AppConfigData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appconfigdata.html#appconfigdata) | ✓ | `session.appconfigdata.client(...)` | `boto3.client("appconfigdata", ...)` |
| [AppFabric](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appfabric.html#appfabric) | ✓ | `session.appfabric.client(...)` | `boto3.client("appfabric", ...)` |
| [Appflow](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#appflow) | ✓ | `session.appflow.client(...)` | `boto3.client("appflow", ...)` |
| [AppIntegrationsService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appintegrations.html#appintegrationsservice) | ✓ | `session.appintegrations.client(...)` | `boto3.client("appintegrations", ...)` |
| [ApplicationAutoScaling](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/application-autoscaling.html#applicationautoscaling) | ✓ | `session.application_autoscaling.client(...)` | `boto3.client("application-autoscaling", ...)` |
| [ApplicationInsights](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/application-insights.html#applicationinsights) | ✓ | `session.application_insights.client(...)` | `boto3.client("application-insights", ...)` |
| [CloudWatchApplicationSignals](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/application-signals.html#cloudwatchapplicationsignals) | ✓ | `session.application_signals.client(...)` | `boto3.client("application-signals", ...)` |
| [ApplicationCostProfiler](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/applicationcostprofiler.html#applicationcostprofiler) | ✓ | `session.applicationcostprofiler.client(...)` | `boto3.client("applicationcostprofiler", ...)` |
| [AppMesh](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appmesh.html#appmesh) | ✓ | `session.appmesh.client(...)` | `boto3.client("appmesh", ...)` |
| [AppRunner](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/apprunner.html#apprunner) | ✓ | `session.apprunner.client(...)` | `boto3.client("apprunner", ...)` |
| [AppStream](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appstream.html#appstream) | ✓ | `session.appstream.client(...)` | `boto3.client("appstream", ...)` |
| [AppSync](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#appsync) | ✓ | `session.appsync.client(...)` | `boto3.client("appsync", ...)` |
| [MainframeModernizationApplicationTesting](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/apptest.html#mainframemodernizationapplicationtesting) | ✓ | `session.apptest.client(...)` | `boto3.client("apptest", ...)` |
| [ARCZonalShift](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/arc-zonal-shift.html#arczonalshift) | ✓ | `session.arc_zonal_shift.client(...)` | `boto3.client("arc-zonal-shift", ...)` |
| [Artifact](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/artifact.html#artifact) | ✓ | `session.artifact.client(...)` | `boto3.client("artifact", ...)` |
| [Athena](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena.html#athena) | ✓ | `session.athena.client(...)` | `boto3.client("athena", ...)` |
| [AuditManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/auditmanager.html#auditmanager) | ✓ | `session.auditmanager.client(...)` | `boto3.client("auditmanager", ...)` |
| [AutoScaling](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/autoscaling.html#autoscaling) | ✓ | `session.autoscaling.client(...)` | `boto3.client("autoscaling", ...)` |
| [AutoScalingPlans](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/autoscaling-plans.html#autoscalingplans) | ✓ | `session.autoscaling_plans.client(...)` | `boto3.client("autoscaling-plans", ...)` |
| [B2BI](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/b2bi.html#b2bi) | ✓ | `session.b2bi.client(...)` | `boto3.client("b2bi", ...)` |
| [Backup](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup.html#backup) | ✓ | `session.backup.client(...)` | `boto3.client("backup", ...)` |
| [BackupGateway](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#backupgateway) | ✓ | `session.backup_gateway.client(...)` | `boto3.client("backup-gateway", ...)` |
| [BackupSearch](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backupsearch.html#backupsearch) | ✓ | `session.backupsearch.client(...)` | `boto3.client("backupsearch", ...)` |
| [Batch](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#batch) | ✓ | `session.batch.client(...)` | `boto3.client("batch", ...)` |
| [BillingandCostManagementDataExports](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bcm-data-exports.html#billingandcostmanagementdataexports) | ✓ | `session.bcm_data_exports.client(...)` | `boto3.client("bcm-data-exports", ...)` |
| [BillingandCostManagementPricingCalculator](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bcm-pricing-calculator.html#billingandcostmanagementpricingcalculator) | ✓ | `session.bcm_pricing_calculator.client(...)` | `boto3.client("bcm-pricing-calculator", ...)` |
| [Bedrock](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock.html#bedrock) | ✓ | `session.bedrock.client(...)` | `boto3.client("bedrock", ...)` |
| [AgentsforBedrock](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-agent.html#agentsforbedrock) | ✓ | `session.bedrock_agent.client(...)` | `boto3.client("bedrock-agent", ...)` |
| [AgentsforBedrockRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-agent-runtime.html#agentsforbedrockruntime) | ✓ | `session.bedrock_agent_runtime.client(...)` | `boto3.client("bedrock-agent-runtime", ...)` |
| [DataAutomationforBedrock](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-data-automation.html#dataautomationforbedrock) | ✓ | `session.bedrock_data_automation.client(...)` | `boto3.client("bedrock-data-automation", ...)` |
| [RuntimeforBedrockDataAutomation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-data-automation-runtime.html#runtimeforbedrockdataautomation) | ✓ | `session.bedrock_data_automation_runtime.client(...)` | `boto3.client("bedrock-data-automation-runtime", ...)` |
| [BedrockRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-runtime.html#bedrockruntime) | ✓ | `session.bedrock_runtime.client(...)` | `boto3.client("bedrock-runtime", ...)` |
| [Billing](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billing.html#billing) | ✓ | `session.billing.client(...)` | `boto3.client("billing", ...)` |
| [BillingConductor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#billingconductor) | ✓ | `session.billingconductor.client(...)` | `boto3.client("billingconductor", ...)` |
| [Braket](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/braket.html#braket) | ✓ | `session.braket.client(...)` | `boto3.client("braket", ...)` |
| [Budgets](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#budgets) | ✓ | `session.budgets.client(...)` | `boto3.client("budgets", ...)` |
| [CostExplorer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#costexplorer) | ✓ | `session.ce.client(...)` | `boto3.client("ce", ...)` |
| [Chatbot](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chatbot.html#chatbot) | ✓ | `session.chatbot.client(...)` | `boto3.client("chatbot", ...)` |
| [Chime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime.html#chime) | ✓ | `session.chime.client(...)` | `boto3.client("chime", ...)` |
| [ChimeSDKIdentity](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#chimesdkidentity) | ✓ | `session.chime_sdk_identity.client(...)` | `boto3.client("chime-sdk-identity", ...)` |
| [ChimeSDKMediaPipelines](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#chimesdkmediapipelines) | ✓ | `session.chime_sdk_media_pipelines.client(...)` | `boto3.client("chime-sdk-media-pipelines", ...)` |
| [ChimeSDKMeetings](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#chimesdkmeetings) | ✓ | `session.chime_sdk_meetings.client(...)` | `boto3.client("chime-sdk-meetings", ...)` |
| [ChimeSDKMessaging](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#chimesdkmessaging) | ✓ | `session.chime_sdk_messaging.client(...)` | `boto3.client("chime-sdk-messaging", ...)` |
| [ChimeSDKVoice](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#chimesdkvoice) | ✓ | `session.chime_sdk_voice.client(...)` | `boto3.client("chime-sdk-voice", ...)` |
| [CleanRoomsService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanrooms.html#cleanroomsservice) | ✓ | `session.cleanrooms.client(...)` | `boto3.client("cleanrooms", ...)` |
| [CleanRoomsML](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml) | ✓ | `session.cleanroomsml.client(...)` | `boto3.client("cleanroomsml", ...)` |
| [Cloud9](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloud9.html#cloud9) | ✓ | `session.cloud9.client(...)` | `boto3.client("cloud9", ...)` |
| [CloudControlApi](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudcontrol.html#cloudcontrolapi) | ✓ | `session.cloudcontrol.client(...)` | `boto3.client("cloudcontrol", ...)` |
| [CloudDirectory](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/clouddirectory.html#clouddirectory) | ✓ | `session.clouddirectory.client(...)` | `boto3.client("clouddirectory", ...)` |
| [CloudFormation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#cloudformation) | ✓ | `session.cloudformation.client(...)`<br />`session.cloudformation.resource(...)` | `boto3.client("cloudformation", ...)`<br />`boto3.resource("cloudformation", ...)` |
| [CloudFront](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudfront.html#cloudfront) | ✓ | `session.cloudfront.client(...)` | `boto3.client("cloudfront", ...)` |
| [CloudFrontKeyValueStore](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudfront-keyvaluestore.html#cloudfrontkeyvaluestore) | ✓ | `session.cloudfront_keyvaluestore.client(...)` | `boto3.client("cloudfront-keyvaluestore", ...)` |
| [CloudHSM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudhsm.html#cloudhsm) | ✓ | `session.cloudhsm.client(...)` | `boto3.client("cloudhsm", ...)` |
| [CloudHSMV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudhsmv2.html#cloudhsmv2) | ✓ | `session.cloudhsmv2.client(...)` | `boto3.client("cloudhsmv2", ...)` |
| [CloudSearch](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearch.html#cloudsearch) | ✓ | `session.cloudsearch.client(...)` | `boto3.client("cloudsearch", ...)` |
| [CloudSearchDomain](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain.html#cloudsearchdomain) | ✓ | `session.cloudsearchdomain.client(...)` | `boto3.client("cloudsearchdomain", ...)` |
| [CloudTrail](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail.html#cloudtrail) | ✓ | `session.cloudtrail.client(...)` | `boto3.client("cloudtrail", ...)` |
| [CloudTrailDataService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data.html#cloudtraildataservice) | ✓ | `session.cloudtrail_data.client(...)` | `boto3.client("cloudtrail-data", ...)` |
| [CloudWatch](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#cloudwatch) | ✓ | `session.cloudwatch.client(...)`<br />`session.cloudwatch.resource(...)` | `boto3.client("cloudwatch", ...)`<br />`boto3.resource("cloudwatch", ...)` |
| [CodeArtifact](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeartifact.html#codeartifact) | ✓ | `session.codeartifact.client(...)` | `boto3.client("codeartifact", ...)` |
| [CodeBuild](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#codebuild) | ✓ | `session.codebuild.client(...)` | `boto3.client("codebuild", ...)` |
| [CodeCatalyst](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codecatalyst.html#codecatalyst) | ✓ | `session.codecatalyst.client(...)` | `boto3.client("codecatalyst", ...)` |
| [CodeCommit](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codecommit.html#codecommit) | ✓ | `session.codecommit.client(...)` | `boto3.client("codecommit", ...)` |
| [CodeConnections](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeconnections.html#codeconnections) | ✓ | `session.codeconnections.client(...)` | `boto3.client("codeconnections", ...)` |
| [CodeDeploy](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#codedeploy) | ✓ | `session.codedeploy.client(...)` | `boto3.client("codedeploy", ...)` |
| [CodeGuruReviewer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-reviewer.html#codegurureviewer) | ✓ | `session.codeguru_reviewer.client(...)` | `boto3.client("codeguru-reviewer", ...)` |
| [CodeGuruSecurity](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguru-security.html#codegurusecurity) | ✓ | `session.codeguru_security.client(...)` | `boto3.client("codeguru-security", ...)` |
| [CodeGuruProfiler](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codeguruprofiler.html#codeguruprofiler) | ✓ | `session.codeguruprofiler.client(...)` | `boto3.client("codeguruprofiler", ...)` |
| [CodePipeline](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codepipeline.html#codepipeline) | ✓ | `session.codepipeline.client(...)` | `boto3.client("codepipeline", ...)` |
| [CodeStarconnections](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-connections.html#codestarconnections) | ✓ | `session.codestar_connections.client(...)` | `boto3.client("codestar-connections", ...)` |
| [CodeStarNotifications](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#codestarnotifications) | ✓ | `session.codestar_notifications.client(...)` | `boto3.client("codestar-notifications", ...)` |
| [CognitoIdentity](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-identity.html#cognitoidentity) | ✓ | `session.cognito_identity.client(...)` | `boto3.client("cognito-identity", ...)` |
| [CognitoIdentityProvider](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-idp.html#cognitoidentityprovider) | ✓ | `session.cognito_idp.client(...)` | `boto3.client("cognito-idp", ...)` |
| [CognitoSync](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#cognitosync) | ✓ | `session.cognito_sync.client(...)` | `boto3.client("cognito-sync", ...)` |
| [Comprehend](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#comprehend) | ✓ | `session.comprehend.client(...)` | `boto3.client("comprehend", ...)` |
| [ComprehendMedical](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehendmedical.html#comprehendmedical) | ✓ | `session.comprehendmedical.client(...)` | `boto3.client("comprehendmedical", ...)` |
| [ComputeOptimizer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/compute-optimizer.html#computeoptimizer) | ✓ | `session.compute_optimizer.client(...)` | `boto3.client("compute-optimizer", ...)` |
| [ConfigService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/config.html#configservice) | ✓ | `session.config.client(...)` | `boto3.client("config", ...)` |
| [Connect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connect.html#connect) | ✓ | `session.connect.client(...)` | `boto3.client("connect", ...)` |
| [ConnectContactLens](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connect-contact-lens.html#connectcontactlens) | ✓ | `session.connect_contact_lens.client(...)` | `boto3.client("connect-contact-lens", ...)` |
| [ConnectCampaignService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcampaigns.html#connectcampaignservice) | ✓ | `session.connectcampaigns.client(...)` | `boto3.client("connectcampaigns", ...)` |
| [ConnectCampaignServiceV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcampaignsv2.html#connectcampaignservicev2) | ✓ | `session.connectcampaignsv2.client(...)` | `boto3.client("connectcampaignsv2", ...)` |
| [ConnectCases](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases.html#connectcases) | ✓ | `session.connectcases.client(...)` | `boto3.client("connectcases", ...)` |
| [ConnectParticipant](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant.html#connectparticipant) | ✓ | `session.connectparticipant.client(...)` | `boto3.client("connectparticipant", ...)` |
| [ControlCatalog](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controlcatalog.html#controlcatalog) | ✓ | `session.controlcatalog.client(...)` | `boto3.client("controlcatalog", ...)` |
| [ControlTower](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/controltower.html#controltower) | ✓ | `session.controltower.client(...)` | `boto3.client("controltower", ...)` |
| [CostOptimizationHub](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cost-optimization-hub.html#costoptimizationhub) | ✓ | `session.cost_optimization_hub.client(...)` | `boto3.client("cost-optimization-hub", ...)` |
| [CostandUsageReportService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cur.html#costandusagereportservice) | ✓ | `session.cur.client(...)` | `boto3.client("cur", ...)` |
| [CustomerProfiles](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/customer-profiles.html#customerprofiles) | ✓ | `session.customer_profiles.client(...)` | `boto3.client("customer-profiles", ...)` |
| [GlueDataBrew](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#gluedatabrew) | ✓ | `session.databrew.client(...)` | `boto3.client("databrew", ...)` |
| [DataExchange](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dataexchange.html#dataexchange) | ✓ | `session.dataexchange.client(...)` | `boto3.client("dataexchange", ...)` |
| [DataPipeline](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datapipeline.html#datapipeline) | ✓ | `session.datapipeline.client(...)` | `boto3.client("datapipeline", ...)` |
| [DataSync](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#datasync) | ✓ | `session.datasync.client(...)` | `boto3.client("datasync", ...)` |
| [DataZone](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datazone.html#datazone) | ✓ | `session.datazone.client(...)` | `boto3.client("datazone", ...)` |
| [DAX](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dax.html#dax) | ✓ | `session.dax.client(...)` | `boto3.client("dax", ...)` |
| [DeadlineCloud](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/deadline.html#deadlinecloud) | ✓ | `session.deadline.client(...)` | `boto3.client("deadline", ...)` |
| [Detective](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/detective.html#detective) | ✓ | `session.detective.client(...)` | `boto3.client("detective", ...)` |
| [DeviceFarm](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devicefarm.html#devicefarm) | ✓ | `session.devicefarm.client(...)` | `boto3.client("devicefarm", ...)` |
| [DevOpsGuru](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#devopsguru) | ✓ | `session.devops_guru.client(...)` | `boto3.client("devops-guru", ...)` |
| [DirectConnect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/directconnect.html#directconnect) | ✓ | `session.directconnect.client(...)` | `boto3.client("directconnect", ...)` |
| [ApplicationDiscoveryService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/discovery.html#applicationdiscoveryservice) | ✓ | `session.discovery.client(...)` | `boto3.client("discovery", ...)` |
| [DLM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dlm.html#dlm) | ✓ | `session.dlm.client(...)` | `boto3.client("dlm", ...)` |
| [DatabaseMigrationService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#databasemigrationservice) | ✓ | `session.dms.client(...)` | `boto3.client("dms", ...)` |
| [DocDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#docdb) | ✓ | `session.docdb.client(...)` | `boto3.client("docdb", ...)` |
| [DocDBElastic](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb-elastic.html#docdbelastic) | ✓ | `session.docdb_elastic.client(...)` | `boto3.client("docdb-elastic", ...)` |
| [Drs](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/drs.html#drs) | ✓ | `session.drs.client(...)` | `boto3.client("drs", ...)` |
| [DirectoryService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#directoryservice) | ✓ | `session.ds.client(...)` | `boto3.client("ds", ...)` |
| [DirectoryServiceData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds-data.html#directoryservicedata) | ✓ | `session.ds_data.client(...)` | `boto3.client("ds-data", ...)` |
| [AuroraDSQL](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dsql.html#auroradsql) | ✓ | `session.dsql.client(...)` | `boto3.client("dsql", ...)` |
| [DynamoDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#dynamodb) | ✓ | `session.dynamodb.client(...)`<br />`session.dynamodb.resource(...)` | `boto3.client("dynamodb", ...)`<br />`boto3.resource("dynamodb", ...)` |
| [DynamoDBStreams](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodbstreams.html#dynamodbstreams) | ✓ | `session.dynamodbstreams.client(...)` | `boto3.client("dynamodbstreams", ...)` |
| [EBS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ebs.html#ebs) | ✓ | `session.ebs.client(...)` | `boto3.client("ebs", ...)` |
| [EC2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#ec2) | ✓ | `session.ec2.client(...)`<br />`session.ec2.resource(...)` | `boto3.client("ec2", ...)`<br />`boto3.resource("ec2", ...)` |
| [EC2InstanceConnect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#ec2instanceconnect) | ✓ | `session.ec2_instance_connect.client(...)` | `boto3.client("ec2-instance-connect", ...)` |
| [ECR](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecr.html#ecr) | ✓ | `session.ecr.client(...)` | `boto3.client("ecr", ...)` |
| [ECRPublic](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecr-public.html#ecrpublic) | ✓ | `session.ecr_public.client(...)` | `boto3.client("ecr-public", ...)` |
| [ECS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ecs) | ✓ | `session.ecs.client(...)` | `boto3.client("ecs", ...)` |
| [EFS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/efs.html#efs) | ✓ | `session.efs.client(...)` | `boto3.client("efs", ...)` |
| [EKS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks.html#eks) | ✓ | `session.eks.client(...)` | `boto3.client("eks", ...)` |
| [EKSAuth](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth.html#eksauth) | ✓ | `session.eks_auth.client(...)` | `boto3.client("eks-auth", ...)` |
| [ElastiCache](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elasticache.html#elasticache) | ✓ | `session.elasticache.client(...)` | `boto3.client("elasticache", ...)` |
| [ElasticBeanstalk](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elasticbeanstalk.html#elasticbeanstalk) | ✓ | `session.elasticbeanstalk.client(...)` | `boto3.client("elasticbeanstalk", ...)` |
| [ElasticTranscoder](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#elastictranscoder) | ✓ | `session.elastictranscoder.client(...)` | `boto3.client("elastictranscoder", ...)` |
| [ElasticLoadBalancing](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#elasticloadbalancing) | ✓ | `session.elb.client(...)` | `boto3.client("elb", ...)` |
| [ElasticLoadBalancingv2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elbv2.html#elasticloadbalancingv2) | ✓ | `session.elbv2.client(...)` | `boto3.client("elbv2", ...)` |
| [EMR](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr.html#emr) | ✓ | `session.emr.client(...)` | `boto3.client("emr", ...)` |
| [EMRContainers](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#emrcontainers) | ✓ | `session.emr_containers.client(...)` | `boto3.client("emr-containers", ...)` |
| [EMRServerless](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-serverless.html#emrserverless) | ✓ | `session.emr_serverless.client(...)` | `boto3.client("emr-serverless", ...)` |
| [EntityResolution](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution.html#entityresolution) | ✓ | `session.entityresolution.client(...)` | `boto3.client("entityresolution", ...)` |
| [ElasticsearchService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#elasticsearchservice) | ✓ | `session.es.client(...)` | `boto3.client("es", ...)` |
| [EventBridge](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events.html#eventbridge) | ✓ | `session.eventbridge.client(...)` | `boto3.client("events", ...)` |
| [CloudWatchEvidently](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#cloudwatchevidently) | ✓ | `session.evidently.client(...)` | `boto3.client("evidently", ...)` |
| [Finspace](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace.html#finspace) | ✓ | `session.finspace.client(...)` | `boto3.client("finspace", ...)` |
| [FinSpaceData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#finspacedata) | ✓ | `session.finspace_data.client(...)` | `boto3.client("finspace-data", ...)` |
| [Firehose](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/firehose.html#firehose) | ✓ | `session.firehose.client(...)` | `boto3.client("firehose", ...)` |
| [FIS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#fis) | ✓ | `session.fis.client(...)` | `boto3.client("fis", ...)` |
| [FMS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fms.html#fms) | ✓ | `session.fms.client(...)` | `boto3.client("fms", ...)` |
| [ForecastService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecast.html#forecastservice) | ✓ | `session.forecast.client(...)` | `boto3.client("forecast", ...)` |
| [ForecastQueryService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#forecastqueryservice) | ✓ | `session.forecastquery.client(...)` | `boto3.client("forecastquery", ...)` |
| [FraudDetector](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/frauddetector.html#frauddetector) | ✓ | `session.frauddetector.client(...)` | `boto3.client("frauddetector", ...)` |
| [FreeTier](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/freetier.html#freetier) | ✓ | `session.freetier.client(...)` | `boto3.client("freetier", ...)` |
| [FSx](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fsx.html#fsx) | ✓ | `session.fsx.client(...)` | `boto3.client("fsx", ...)` |
| [GameLift](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamelift.html#gamelift) | ✓ | `session.gamelift.client(...)` | `boto3.client("gamelift", ...)` |
| [LocationServiceMapsV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/geo-maps.html#locationservicemapsv2) | ✓ | `session.geo_maps.client(...)` | `boto3.client("geo-maps", ...)` |
| [LocationServicePlacesV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/geo-places.html#locationserviceplacesv2) | ✓ | `session.geo_places.client(...)` | `boto3.client("geo-places", ...)` |
| [LocationServiceRoutesV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/geo-routes.html#locationserviceroutesv2) | ✓ | `session.geo_routes.client(...)` | `boto3.client("geo-routes", ...)` |
| [Glacier](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glacier.html#glacier) | ✓ | `session.glacier.client(...)`<br />`session.glacier.resource(...)` | `boto3.client("glacier", ...)`<br />`boto3.resource("glacier", ...)` |
| [GlobalAccelerator](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/globalaccelerator.html#globalaccelerator) | ✓ | `session.globalaccelerator.client(...)` | `boto3.client("globalaccelerator", ...)` |
| [Glue](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glue.html#glue) | ✓ | `session.glue.client(...)` | `boto3.client("glue", ...)` |
| [ManagedGrafana](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/grafana.html#managedgrafana) | ✓ | `session.grafana.client(...)` | `boto3.client("grafana", ...)` |
| [Greengrass](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/greengrass.html#greengrass) | ✓ | `session.greengrass.client(...)` | `boto3.client("greengrass", ...)` |
| [GreengrassV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/greengrassv2.html#greengrassv2) | ✓ | `session.greengrassv2.client(...)` | `boto3.client("greengrassv2", ...)` |
| [GroundStation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/groundstation.html#groundstation) | ✓ | `session.groundstation.client(...)` | `boto3.client("groundstation", ...)` |
| [GuardDuty](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/guardduty.html#guardduty) | ✓ | `session.guardduty.client(...)` | `boto3.client("guardduty", ...)` |
| [Health](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/health.html#health) | ✓ | `session.health.client(...)` | `boto3.client("health", ...)` |
| [HealthLake](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/healthlake.html#healthlake) | ✓ | `session.healthlake.client(...)` | `boto3.client("healthlake", ...)` |
| [IAM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iam.html#iam) | ✓ | `session.iam.client(...)`<br />`session.iam.resource(...)` | `boto3.client("iam", ...)`<br />`boto3.resource("iam", ...)` |
| [IdentityStore](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/identitystore.html#identitystore) | ✓ | `session.identitystore.client(...)` | `boto3.client("identitystore", ...)` |
| [Imagebuilder](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder) | ✓ | `session.imagebuilder.client(...)` | `boto3.client("imagebuilder", ...)` |
| [ImportExport](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/importexport.html#importexport) | ✓ | `session.importexport.client(...)` | `boto3.client("importexport", ...)` |
| [Inspector](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/inspector.html#inspector) | ✓ | `session.inspector.client(...)` | `boto3.client("inspector", ...)` |
| [Inspectorscan](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/inspector-scan.html#inspectorscan) | ✓ | `session.inspector_scan.client(...)` | `boto3.client("inspector-scan", ...)` |
| [Inspector2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/inspector2.html#inspector2) | ✓ | `session.inspector2.client(...)` | `boto3.client("inspector2", ...)` |
| [CloudWatchInternetMonitor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/internetmonitor.html#cloudwatchinternetmonitor) | ✓ | `session.internetmonitor.client(...)` | `boto3.client("internetmonitor", ...)` |
| [Invoicing](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/invoicing.html#invoicing) | ✓ | `session.invoicing.client(...)` | `boto3.client("invoicing", ...)` |
| [IoT](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot.html#iot) | ✓ | `session.iot.client(...)` | `boto3.client("iot", ...)` |
| [IoTDataPlane](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#iotdataplane) | ✓ | `session.iot_data.client(...)` | `boto3.client("iot-data", ...)` |
| [IoTJobsDataPlane](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-jobs-data.html#iotjobsdataplane) | ✓ | `session.iot_jobs_data.client(...)` | `boto3.client("iot-jobs-data", ...)` |
| [IoTAnalytics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#iotanalytics) | ✓ | `session.iotanalytics.client(...)` | `boto3.client("iotanalytics", ...)` |
| [IoTDeviceAdvisor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotdeviceadvisor.html#iotdeviceadvisor) | ✓ | `session.iotdeviceadvisor.client(...)` | `boto3.client("iotdeviceadvisor", ...)` |
| [IoTEvents](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotevents.html#iotevents) | ✓ | `session.iotevents.client(...)` | `boto3.client("iotevents", ...)` |
| [IoTEventsData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotevents-data.html#ioteventsdata) | ✓ | `session.iotevents_data.client(...)` | `boto3.client("iotevents-data", ...)` |
| [IoTFleetHub](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotfleethub.html#iotfleethub) | ✓ | `session.iotfleethub.client(...)` | `boto3.client("iotfleethub", ...)` |
| [IoTFleetWise](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotfleetwise.html#iotfleetwise) | ✓ | `session.iotfleetwise.client(...)` | `boto3.client("iotfleetwise", ...)` |
| [IoTSecureTunneling](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsecuretunneling.html#iotsecuretunneling) | ✓ | `session.iotsecuretunneling.client(...)` | `boto3.client("iotsecuretunneling", ...)` |
| [IoTSiteWise](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise.html#iotsitewise) | ✓ | `session.iotsitewise.client(...)` | `boto3.client("iotsitewise", ...)` |
| [IoTThingsGraph](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotthingsgraph.html#iotthingsgraph) | ✓ | `session.iotthingsgraph.client(...)` | `boto3.client("iotthingsgraph", ...)` |
| [IoTTwinMaker](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iottwinmaker.html#iottwinmaker) | ✓ | `session.iottwinmaker.client(...)` | `boto3.client("iottwinmaker", ...)` |
| [IoTWireless](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotwireless.html#iotwireless) | ✓ | `session.iotwireless.client(...)` | `boto3.client("iotwireless", ...)` |
| [IVS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs.html#ivs) | ✓ | `session.ivs.client(...)` | `boto3.client("ivs", ...)` |
| [Ivsrealtime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime.html#ivsrealtime) | ✓ | `session.ivs_realtime.client(...)` | `boto3.client("ivs-realtime", ...)` |
| [Ivschat](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivschat.html#ivschat) | ✓ | `session.ivschat.client(...)` | `boto3.client("ivschat", ...)` |
| [Kafka](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#kafka) | ✓ | `session.kafka.client(...)` | `boto3.client("kafka", ...)` |
| [KafkaConnect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafkaconnect.html#kafkaconnect) | ✓ | `session.kafkaconnect.client(...)` | `boto3.client("kafkaconnect", ...)` |
| [Kendra](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kendra.html#kendra) | ✓ | `session.kendra.client(...)` | `boto3.client("kendra", ...)` |
| [KendraRanking](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kendra-ranking.html#kendraranking) | ✓ | `session.kendra_ranking.client(...)` | `boto3.client("kendra-ranking", ...)` |
| [Keyspaces](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/keyspaces.html#keyspaces) | ✓ | `session.keyspaces.client(...)` | `boto3.client("keyspaces", ...)` |
| [Kinesis](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesis.html#kinesis) | ✓ | `session.kinesis.client(...)` | `boto3.client("kinesis", ...)` |
| [KinesisVideoArchivedMedia](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesis-video-archived-media.html#kinesisvideoarchivedmedia) | ✓ | `session.kinesis_video_archived_media.client(...)` | `boto3.client("kinesis-video-archived-media", ...)` |
| [KinesisVideoMedia](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesis-video-media.html#kinesisvideomedia) | ✓ | `session.kinesis_video_media.client(...)` | `boto3.client("kinesis-video-media", ...)` |
| [KinesisVideoSignalingChannels](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesis-video-signaling.html#kinesisvideosignalingchannels) | ✓ | `session.kinesis_video_signaling.client(...)` | `boto3.client("kinesis-video-signaling", ...)` |
| [KinesisVideoWebRTCStorage](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesis-video-webrtc-storage.html#kinesisvideowebrtcstorage) | ✓ | `session.kinesis_video_webrtc_storage.client(...)` | `boto3.client("kinesis-video-webrtc-storage", ...)` |
| [KinesisAnalytics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalytics.html#kinesisanalytics) | ✓ | `session.kinesisanalytics.client(...)` | `boto3.client("kinesisanalytics", ...)` |
| [KinesisAnalyticsV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#kinesisanalyticsv2) | ✓ | `session.kinesisanalyticsv2.client(...)` | `boto3.client("kinesisanalyticsv2", ...)` |
| [KinesisVideo](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisvideo.html#kinesisvideo) | ✓ | `session.kinesisvideo.client(...)` | `boto3.client("kinesisvideo", ...)` |
| [KMS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kms.html#kms) | ✓ | `session.kms.client(...)` | `boto3.client("kms", ...)` |
| [LakeFormation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lakeformation.html#lakeformation) | ✓ | `session.lakeformation.client(...)` | `boto3.client("lakeformation", ...)` |
| [Lambda](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lambda.html#lambda) | ✓ | `session.lambda_.client(...)` | `boto3.client("lambda", ...)` |
| [LaunchWizard](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/launch-wizard.html#launchwizard) | ✓ | `session.launch_wizard.client(...)` | `boto3.client("launch-wizard", ...)` |
| [LexModelBuildingService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lex-models.html#lexmodelbuildingservice) | ✓ | `session.lex_models.client(...)` | `boto3.client("lex-models", ...)` |
| [LexRuntimeService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lex-runtime.html#lexruntimeservice) | ✓ | `session.lex_runtime.client(...)` | `boto3.client("lex-runtime", ...)` |
| [LexModelsV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lexv2-models.html#lexmodelsv2) | ✓ | `session.lexv2_models.client(...)` | `boto3.client("lexv2-models", ...)` |
| [LexRuntimeV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lexv2-runtime.html#lexruntimev2) | ✓ | `session.lexv2_runtime.client(...)` | `boto3.client("lexv2-runtime", ...)` |
| [LicenseManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager.html#licensemanager) | ✓ | `session.license_manager.client(...)` | `boto3.client("license-manager", ...)` |
| [LicenseManagerLinuxSubscriptions](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager-linux-subscriptions.html#licensemanagerlinuxsubscriptions) | ✓ | `session.license_manager_linux_subscriptions.client(...)` | `boto3.client("license-manager-linux-subscriptions", ...)` |
| [LicenseManagerUserSubscriptions](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/license-manager-user-subscriptions.html#licensemanagerusersubscriptions) | ✓ | `session.license_manager_user_subscriptions.client(...)` | `boto3.client("license-manager-user-subscriptions", ...)` |
| [Lightsail](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lightsail.html#lightsail) | ✓ | `session.lightsail.client(...)` | `boto3.client("lightsail", ...)` |
| [LocationService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/location.html#locationservice) | ✓ | `session.location.client(...)` | `boto3.client("location", ...)` |
| [CloudWatchLogs](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/logs.html#cloudwatchlogs) | ✓ | `session.logs.client(...)` | `boto3.client("logs", ...)` |
| [LookoutEquipment](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutequipment.html#lookoutequipment) | ✓ | `session.lookoutequipment.client(...)` | `boto3.client("lookoutequipment", ...)` |
| [LookoutMetrics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics.html#lookoutmetrics) | ✓ | `session.lookoutmetrics.client(...)` | `boto3.client("lookoutmetrics", ...)` |
| [LookoutforVision](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutvision.html#lookoutforvision) | ✓ | `session.lookoutvision.client(...)` | `boto3.client("lookoutvision", ...)` |
| [MainframeModernization](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/m2.html#mainframemodernization) | ✓ | `session.m2.client(...)` | `boto3.client("m2", ...)` |
| [MachineLearning](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/machinelearning.html#machinelearning) | ✓ | `session.machinelearning.client(...)` | `boto3.client("machinelearning", ...)` |
| [Macie2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/macie2.html#macie2) | ✓ | `session.macie2.client(...)` | `boto3.client("macie2", ...)` |
| [MailManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager.html#mailmanager) | ✓ | `session.mailmanager.client(...)` | `boto3.client("mailmanager", ...)` |
| [ManagedBlockchain](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain.html#managedblockchain) | ✓ | `session.managedblockchain.client(...)` | `boto3.client("managedblockchain", ...)` |
| [ManagedBlockchainQuery](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query.html#managedblockchainquery) | ✓ | `session.managedblockchain_query.client(...)` | `boto3.client("managedblockchain-query", ...)` |
| [AgreementService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplace-agreement.html#agreementservice) | ✓ | `session.marketplace_agreement.client(...)` | `boto3.client("marketplace-agreement", ...)` |
| [MarketplaceCatalog](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplace-catalog.html#marketplacecatalog) | ✓ | `session.marketplace_catalog.client(...)` | `boto3.client("marketplace-catalog", ...)` |
| [MarketplaceDeploymentService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplace-deployment.html#marketplacedeploymentservice) | ✓ | `session.marketplace_deployment.client(...)` | `boto3.client("marketplace-deployment", ...)` |
| [MarketplaceEntitlementService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplace-entitlement.html#marketplaceentitlementservice) | ✓ | `session.marketplace_entitlement.client(...)` | `boto3.client("marketplace-entitlement", ...)` |
| [MarketplaceReportingService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplace-reporting.html#marketplacereportingservice) | ✓ | `session.marketplace_reporting.client(...)` | `boto3.client("marketplace-reporting", ...)` |
| [MarketplaceCommerceAnalytics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/marketplacecommerceanalytics.html#marketplacecommerceanalytics) | ✓ | `session.marketplacecommerceanalytics.client(...)` | `boto3.client("marketplacecommerceanalytics", ...)` |
| [MediaConnect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediaconnect.html#mediaconnect) | ✓ | `session.mediaconnect.client(...)` | `boto3.client("mediaconnect", ...)` |
| [MediaConvert](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediaconvert.html#mediaconvert) | ✓ | `session.mediaconvert.client(...)` | `boto3.client("mediaconvert", ...)` |
| [MediaLive](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medialive.html#medialive) | ✓ | `session.medialive.client(...)` | `boto3.client("medialive", ...)` |
| [MediaPackage](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediapackage.html#mediapackage) | ✓ | `session.mediapackage.client(...)` | `boto3.client("mediapackage", ...)` |
| [MediaPackageVod](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediapackage-vod.html#mediapackagevod) | ✓ | `session.mediapackage_vod.client(...)` | `boto3.client("mediapackage-vod", ...)` |
| [Mediapackagev2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediapackagev2.html#mediapackagev2) | ✓ | `session.mediapackagev2.client(...)` | `boto3.client("mediapackagev2", ...)` |
| [MediaStore](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore.html#mediastore) | ✓ | `session.mediastore.client(...)` | `boto3.client("mediastore", ...)` |
| [MediaStoreData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data.html#mediastoredata) | ✓ | `session.mediastore_data.client(...)` | `boto3.client("mediastore-data", ...)` |
| [MediaTailor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#mediatailor) | ✓ | `session.mediatailor.client(...)` | `boto3.client("mediatailor", ...)` |
| [HealthImaging](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medical-imaging.html#healthimaging) | ✓ | `session.medical_imaging.client(...)` | `boto3.client("medical-imaging", ...)` |
| [MemoryDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/memorydb.html#memorydb) | ✓ | `session.memorydb.client(...)` | `boto3.client("memorydb", ...)` |
| [MarketplaceMetering](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/meteringmarketplace.html#marketplacemetering) | ✓ | `session.meteringmarketplace.client(...)` | `boto3.client("meteringmarketplace", ...)` |
| [MigrationHub](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgh.html#migrationhub) | ✓ | `session.mgh.client(...)` | `boto3.client("mgh", ...)` |
| [Mgn](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn) | ✓ | `session.mgn.client(...)` | `boto3.client("mgn", ...)` |
| [MigrationHubRefactorSpaces](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migration-hub-refactor-spaces.html#migrationhubrefactorspaces) | ✓ | `session.migration_hub_refactor_spaces.client(...)` | `boto3.client("migration-hub-refactor-spaces", ...)` |
| [MigrationHubConfig](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhub-config.html#migrationhubconfig) | ✓ | `session.migrationhub_config.client(...)` | `boto3.client("migrationhub-config", ...)` |
| [MigrationHubOrchestrator](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhuborchestrator.html#migrationhuborchestrator) | ✓ | `session.migrationhuborchestrator.client(...)` | `boto3.client("migrationhuborchestrator", ...)` |
| [MigrationHubStrategyRecommendations](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#migrationhubstrategyrecommendations) | ✓ | `session.migrationhubstrategy.client(...)` | `boto3.client("migrationhubstrategy", ...)` |
| [MQ](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mq.html#mq) | ✓ | `session.mq.client(...)` | `boto3.client("mq", ...)` |
| [MTurk](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mturk.html#mturk) | ✓ | `session.mturk.client(...)` | `boto3.client("mturk", ...)` |
| [MWAA](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mwaa.html#mwaa) | ✓ | `session.mwaa.client(...)` | `boto3.client("mwaa", ...)` |
| [Neptune](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/neptune.html#neptune) | ✓ | `session.neptune.client(...)` | `boto3.client("neptune", ...)` |
| [NeptuneGraph](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/neptune-graph.html#neptunegraph) | ✓ | `session.neptune_graph.client(...)` | `boto3.client("neptune-graph", ...)` |
| [NeptuneData](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/neptunedata.html#neptunedata) | ✓ | `session.neptunedata.client(...)` | `boto3.client("neptunedata", ...)` |
| [NetworkFirewall](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/network-firewall.html#networkfirewall) | ✓ | `session.network_firewall.client(...)` | `boto3.client("network-firewall", ...)` |
| [NetworkFlowMonitor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkflowmonitor.html#networkflowmonitor) | ✓ | `session.networkflowmonitor.client(...)` | `boto3.client("networkflowmonitor", ...)` |
| [NetworkManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#networkmanager) | ✓ | `session.networkmanager.client(...)` | `boto3.client("networkmanager", ...)` |
| [CloudWatchNetworkMonitor](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmonitor.html#cloudwatchnetworkmonitor) | ✓ | `session.networkmonitor.client(...)` | `boto3.client("networkmonitor", ...)` |
| [UserNotifications](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notifications.html#usernotifications) | ✓ | `session.notifications.client(...)` | `boto3.client("notifications", ...)` |
| [UserNotificationsContacts](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/notificationscontacts.html#usernotificationscontacts) | ✓ | `session.notificationscontacts.client(...)` | `boto3.client("notificationscontacts", ...)` |
| [CloudWatchObservabilityAccessManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/oam.html#cloudwatchobservabilityaccessmanager) | ✓ | `session.oam.client(...)` | `boto3.client("oam", ...)` |
| [CloudWatchObservabilityAdminService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/observabilityadmin.html#cloudwatchobservabilityadminservice) | ✓ | `session.observabilityadmin.client(...)` | `boto3.client("observabilityadmin", ...)` |
| [Omics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/omics.html#omics) | ✓ | `session.omics.client(...)` | `boto3.client("omics", ...)` |
| [OpenSearchService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#opensearchservice) | ✓ | `session.opensearch.client(...)` | `boto3.client("opensearch", ...)` |
| [OpenSearchServiceServerless](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#opensearchserviceserverless) | ✓ | `session.opensearchserverless.client(...)` | `boto3.client("opensearchserverless", ...)` |
| [OpsWorks](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opsworks.html#opsworks) | ✓ | `session.opsworks.client(...)`<br />`session.opsworks.resource(...)` | `boto3.client("opsworks", ...)`<br />`boto3.resource("opsworks", ...)` |
| [OpsWorksCM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opsworkscm.html#opsworkscm) | ✓ | `session.opsworkscm.client(...)` | `boto3.client("opsworkscm", ...)` |
| [Organizations](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/organizations.html#organizations) | ✓ | `session.organizations.client(...)` | `boto3.client("organizations", ...)` |
| [OpenSearchIngestion](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/osis.html#opensearchingestion) | ✓ | `session.osis.client(...)` | `boto3.client("osis", ...)` |
| [Outposts](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#outposts) | ✓ | `session.outposts.client(...)` | `boto3.client("outposts", ...)` |
| [Panorama](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/panorama.html#panorama) | ✓ | `session.panorama.client(...)` | `boto3.client("panorama", ...)` |
| [PartnerCentralSellingAPI](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/partnercentral-selling.html#partnercentralsellingapi) | ✓ | `session.partnercentral_selling.client(...)` | `boto3.client("partnercentral-selling", ...)` |
| [PaymentCryptographyControlPlane](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/payment-cryptography.html#paymentcryptographycontrolplane) | ✓ | `session.payment_cryptography.client(...)` | `boto3.client("payment-cryptography", ...)` |
| [PaymentCryptographyDataPlane](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/payment-cryptography-data.html#paymentcryptographydataplane) | ✓ | `session.payment_cryptography_data.client(...)` | `boto3.client("payment-cryptography-data", ...)` |
| [PcaConnectorAd](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-ad.html#pcaconnectorad) | ✓ | `session.pca_connector_ad.client(...)` | `boto3.client("pca-connector-ad", ...)` |
| [PrivateCAConnectorforSCEP](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pca-connector-scep.html#privatecaconnectorforscep) | ✓ | `session.pca_connector_scep.client(...)` | `boto3.client("pca-connector-scep", ...)` |
| [ParallelComputingService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pcs.html#parallelcomputingservice) | ✓ | `session.pcs.client(...)` | `boto3.client("pcs", ...)` |
| [Personalize](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize.html#personalize) | ✓ | `session.personalize.client(...)` | `boto3.client("personalize", ...)` |
| [PersonalizeEvents](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-events.html#personalizeevents) | ✓ | `session.personalize_events.client(...)` | `boto3.client("personalize-events", ...)` |
| [PersonalizeRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-runtime.html#personalizeruntime) | ✓ | `session.personalize_runtime.client(...)` | `boto3.client("personalize-runtime", ...)` |
| [PI](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pi.html#pi) | ✓ | `session.pi.client(...)` | `boto3.client("pi", ...)` |
| [Pinpoint](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint.html#pinpoint) | ✓ | `session.pinpoint.client(...)` | `boto3.client("pinpoint", ...)` |
| [PinpointEmail](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-email.html#pinpointemail) | ✓ | `session.pinpoint_email.client(...)` | `boto3.client("pinpoint-email", ...)` |
| [PinpointSMSVoice](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-sms-voice.html#pinpointsmsvoice) | ✓ | `session.pinpoint_sms_voice.client(...)` | `boto3.client("pinpoint-sms-voice", ...)` |
| [PinpointSMSVoiceV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-sms-voice-v2.html#pinpointsmsvoicev2) | ✓ | `session.pinpoint_sms_voice_v2.client(...)` | `boto3.client("pinpoint-sms-voice-v2", ...)` |
| [EventBridgePipes](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pipes.html#eventbridgepipes) | ✓ | `session.pipes.client(...)` | `boto3.client("pipes", ...)` |
| [Polly](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/polly.html#polly) | ✓ | `session.polly.client(...)` | `boto3.client("polly", ...)` |
| [Pricing](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pricing.html#pricing) | ✓ | `session.pricing.client(...)` | `boto3.client("pricing", ...)` |
| [Private5G](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/privatenetworks.html#private5g) | ✓ | `session.privatenetworks.client(...)` | `boto3.client("privatenetworks", ...)` |
| [Proton](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#proton) | ✓ | `session.proton.client(...)` | `boto3.client("proton", ...)` |
| [QApps](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qapps.html#qapps) | ✓ | `session.qapps.client(...)` | `boto3.client("qapps", ...)` |
| [QBusiness](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness.html#qbusiness) | ✓ | `session.qbusiness.client(...)` | `boto3.client("qbusiness", ...)` |
| [QConnect](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qconnect.html#qconnect) | ✓ | `session.qconnect.client(...)` | `boto3.client("qconnect", ...)` |
| [QLDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qldb.html#qldb) | ✓ | `session.qldb.client(...)` | `boto3.client("qldb", ...)` |
| [QLDBSession](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qldb-session.html#qldbsession) | ✓ | `session.qldb_session.client(...)` | `boto3.client("qldb-session", ...)` |
| [QuickSight](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/quicksight.html#quicksight) | ✓ | `session.quicksight.client(...)` | `boto3.client("quicksight", ...)` |
| [RAM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ram.html#ram) | ✓ | `session.ram.client(...)` | `boto3.client("ram", ...)` |
| [RecycleBin](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#recyclebin) | ✓ | `session.rbin.client(...)` | `boto3.client("rbin", ...)` |
| [RDS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#rds) | ✓ | `session.rds.client(...)` | `boto3.client("rds", ...)` |
| [RDSDataService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#rdsdataservice) | ✓ | `session.rds_data.client(...)` | `boto3.client("rds-data", ...)` |
| [Redshift](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift.html#redshift) | ✓ | `session.redshift.client(...)` | `boto3.client("redshift", ...)` |
| [RedshiftDataAPIService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#redshiftdataapiservice) | ✓ | `session.redshift_data.client(...)` | `boto3.client("redshift-data", ...)` |
| [RedshiftServerless](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#redshiftserverless) | ✓ | `session.redshift_serverless.client(...)` | `boto3.client("redshift-serverless", ...)` |
| [Rekognition](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition.html#rekognition) | ✓ | `session.rekognition.client(...)` | `boto3.client("rekognition", ...)` |
| [RePostPrivate](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/repostspace.html#repostprivate) | ✓ | `session.repostspace.client(...)` | `boto3.client("repostspace", ...)` |
| [ResilienceHub](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resiliencehub.html#resiliencehub) | ✓ | `session.resiliencehub.client(...)` | `boto3.client("resiliencehub", ...)` |
| [ResourceExplorer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-explorer-2.html#resourceexplorer) | ✓ | `session.resource_explorer_2.client(...)` | `boto3.client("resource-explorer-2", ...)` |
| [ResourceGroups](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#resourcegroups) | ✓ | `session.resource_groups.client(...)` | `boto3.client("resource-groups", ...)` |
| [ResourceGroupsTaggingAPI](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resourcegroupstaggingapi.html#resourcegroupstaggingapi) | ✓ | `session.resourcegroupstaggingapi.client(...)` | `boto3.client("resourcegroupstaggingapi", ...)` |
| [RoboMaker](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#robomaker) | ✓ | `session.robomaker.client(...)` | `boto3.client("robomaker", ...)` |
| [IAMRolesAnywhere](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#iamrolesanywhere) | ✓ | `session.rolesanywhere.client(...)` | `boto3.client("rolesanywhere", ...)` |
| [Route53](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53.html#route53) | ✓ | `session.route53.client(...)` | `boto3.client("route53", ...)` |
| [Route53RecoveryCluster](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster.html#route53recoverycluster) | ✓ | `session.route53_recovery_cluster.client(...)` | `boto3.client("route53-recovery-cluster", ...)` |
| [Route53RecoveryControlConfig](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-control-config.html#route53recoverycontrolconfig) | ✓ | `session.route53_recovery_control_config.client(...)` | `boto3.client("route53-recovery-control-config", ...)` |
| [Route53RecoveryReadiness](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-readiness.html#route53recoveryreadiness) | ✓ | `session.route53_recovery_readiness.client(...)` | `boto3.client("route53-recovery-readiness", ...)` |
| [Route53Domains](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53domains.html#route53domains) | ✓ | `session.route53domains.client(...)` | `boto3.client("route53domains", ...)` |
| [Route53Profiles](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53profiles.html#route53profiles) | ✓ | `session.route53profiles.client(...)` | `boto3.client("route53profiles", ...)` |
| [Route53Resolver](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53resolver.html#route53resolver) | ✓ | `session.route53resolver.client(...)` | `boto3.client("route53resolver", ...)` |
| [CloudWatchRUM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#cloudwatchrum) | ✓ | `session.rum.client(...)` | `boto3.client("rum", ...)` |
| [S3](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#s3) | ✓ | `session.s3.client(...)`<br />`session.s3.resource(...)` | `boto3.client("s3", ...)`<br />`boto3.resource("s3", ...)` |
| [S3Control](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3control.html#s3control) | ✓ | `session.s3control.client(...)` | `boto3.client("s3control", ...)` |
| [S3Outposts](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#s3outposts) | ✓ | `session.s3outposts.client(...)` | `boto3.client("s3outposts", ...)` |
| [S3Tables](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3tables.html#s3tables) | ✓ | `session.s3tables.client(...)` | `boto3.client("s3tables", ...)` |
| [SageMaker](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker.html#sagemaker) | ✓ | `session.sagemaker.client(...)` | `boto3.client("sagemaker", ...)` |
| [AugmentedAIRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime.html#augmentedairuntime) | ✓ | `session.sagemaker_a2i_runtime.client(...)` | `boto3.client("sagemaker-a2i-runtime", ...)` |
| [SagemakerEdgeManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-edge.html#sagemakeredgemanager) | ✓ | `session.sagemaker_edge.client(...)` | `boto3.client("sagemaker-edge", ...)` |
| [SageMakerFeatureStoreRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-featurestore-runtime.html#sagemakerfeaturestoreruntime) | ✓ | `session.sagemaker_featurestore_runtime.client(...)` | `boto3.client("sagemaker-featurestore-runtime", ...)` |
| [SageMakergeospatialcapabilities](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-geospatial.html#sagemakergeospatialcapabilities) | ✓ | `session.sagemaker_geospatial.client(...)` | `boto3.client("sagemaker-geospatial", ...)` |
| [SageMakerMetrics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-metrics.html#sagemakermetrics) | ✓ | `session.sagemaker_metrics.client(...)` | `boto3.client("sagemaker-metrics", ...)` |
| [SageMakerRuntime](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-runtime.html#sagemakerruntime) | ✓ | `session.sagemaker_runtime.client(...)` | `boto3.client("sagemaker-runtime", ...)` |
| [SavingsPlans](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/savingsplans.html#savingsplans) | ✓ | `session.savingsplans.client(...)` | `boto3.client("savingsplans", ...)` |
| [EventBridgeScheduler](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/scheduler.html#eventbridgescheduler) | ✓ | `session.scheduler.client(...)` | `boto3.client("scheduler", ...)` |
| [Schemas](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/schemas.html#schemas) | ✓ | `session.schemas.client(...)` | `boto3.client("schemas", ...)` |
| [SimpleDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sdb.html#simpledb) | ✓ | `session.sdb.client(...)` | `boto3.client("sdb", ...)` |
| [SecretsManager](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#secretsmanager) | ✓ | `session.secretsmanager.client(...)` | `boto3.client("secretsmanager", ...)` |
| [SecurityIncidentResponse](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/security-ir.html#securityincidentresponse) | ✓ | `session.security_ir.client(...)` | `boto3.client("security-ir", ...)` |
| [SecurityHub](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securityhub.html#securityhub) | ✓ | `session.securityhub.client(...)` | `boto3.client("securityhub", ...)` |
| [SecurityLake](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securitylake.html#securitylake) | ✓ | `session.securitylake.client(...)` | `boto3.client("securitylake", ...)` |
| [ServerlessApplicationRepository](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/serverlessrepo.html#serverlessapplicationrepository) | ✓ | `session.serverlessrepo.client(...)` | `boto3.client("serverlessrepo", ...)` |
| [ServiceQuotas](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/service-quotas.html#servicequotas) | ✓ | `session.service_quotas.client(...)` | `boto3.client("service-quotas", ...)` |
| [ServiceCatalog](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/servicecatalog.html#servicecatalog) | ✓ | `session.servicecatalog.client(...)` | `boto3.client("servicecatalog", ...)` |
| [AppRegistry](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/servicecatalog-appregistry.html#appregistry) | ✓ | `session.servicecatalog_appregistry.client(...)` | `boto3.client("servicecatalog-appregistry", ...)` |
| [ServiceDiscovery](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/servicediscovery.html#servicediscovery) | ✓ | `session.servicediscovery.client(...)` | `boto3.client("servicediscovery", ...)` |
| [SES](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ses.html#ses) | ✓ | `session.ses.client(...)` | `boto3.client("ses", ...)` |
| [SESV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sesv2.html#sesv2) | ✓ | `session.sesv2.client(...)` | `boto3.client("sesv2", ...)` |
| [Shield](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/shield.html#shield) | ✓ | `session.shield.client(...)` | `boto3.client("shield", ...)` |
| [Signer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/signer.html#signer) | ✓ | `session.signer.client(...)` | `boto3.client("signer", ...)` |
| [SimSpaceWeaver](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/simspaceweaver.html#simspaceweaver) | ✓ | `session.simspaceweaver.client(...)` | `boto3.client("simspaceweaver", ...)` |
| [SMS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sms.html#sms) | ✓ | `session.sms.client(...)` | `boto3.client("sms", ...)` |
| [SMSVoice](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sms-voice.html#smsvoice) | ✓ | `session.sms_voice.client(...)` | `boto3.client("sms-voice", ...)` |
| [SnowDeviceManagement](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/snow-device-management.html#snowdevicemanagement) | ✓ | `session.snow_device_management.client(...)` | `boto3.client("snow-device-management", ...)` |
| [Snowball](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/snowball.html#snowball) | ✓ | `session.snowball.client(...)` | `boto3.client("snowball", ...)` |
| [SNS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sns.html#sns) | ✓ | `session.sns.client(...)`<br />`session.sns.resource(...)` | `boto3.client("sns", ...)`<br />`boto3.resource("sns", ...)` |
| [EndUserMessagingSocial](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/socialmessaging.html#endusermessagingsocial) | ✓ | `session.socialmessaging.client(...)` | `boto3.client("socialmessaging", ...)` |
| [SQS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sqs.html#sqs) | ✓ | `session.sqs.client(...)`<br />`session.sqs.resource(...)` | `boto3.client("sqs", ...)`<br />`boto3.resource("sqs", ...)` |
| [SSM](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#ssm) | ✓ | `session.ssm.client(...)` | `boto3.client("ssm", ...)` |
| [SSMContacts](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm-contacts.html#ssmcontacts) | ✓ | `session.ssm_contacts.client(...)` | `boto3.client("ssm-contacts", ...)` |
| [SSMIncidents](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm-incidents.html#ssmincidents) | ✓ | `session.ssm_incidents.client(...)` | `boto3.client("ssm-incidents", ...)` |
| [SystemsManagerQuickSetup](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm-quicksetup.html#systemsmanagerquicksetup) | ✓ | `session.ssm_quicksetup.client(...)` | `boto3.client("ssm-quicksetup", ...)` |
| [SsmSap](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm-sap.html#ssmsap) | ✓ | `session.ssm_sap.client(...)` | `boto3.client("ssm-sap", ...)` |
| [SSO](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso.html#sso) | ✓ | `session.sso.client(...)` | `boto3.client("sso", ...)` |
| [SSOAdmin](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#ssoadmin) | ✓ | `session.sso_admin.client(...)` | `boto3.client("sso-admin", ...)` |
| [SSOOIDC](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#ssooidc) | ✓ | `session.sso_oidc.client(...)` | `boto3.client("sso-oidc", ...)` |
| [SFN](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions.html#sfn) | ✓ | `session.stepfunctions.client(...)` | `boto3.client("stepfunctions", ...)` |
| [StorageGateway](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway.html#storagegateway) | ✓ | `session.storagegateway.client(...)` | `boto3.client("storagegateway", ...)` |
| [STS](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#sts) | ✓ | `session.sts.client(...)` | `boto3.client("sts", ...)` |
| [SupplyChain](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/supplychain.html#supplychain) | ✓ | `session.supplychain.client(...)` | `boto3.client("supplychain", ...)` |
| [Support](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support.html#support) | ✓ | `session.support.client(...)` | `boto3.client("support", ...)` |
| [SupportApp](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support-app.html#supportapp) | ✓ | `session.support_app.client(...)` | `boto3.client("support-app", ...)` |
| [SWF](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/swf.html#swf) | ✓ | `session.swf.client(...)` | `boto3.client("swf", ...)` |
| [Synthetics](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/synthetics.html#synthetics) | ✓ | `session.synthetics.client(...)` | `boto3.client("synthetics", ...)` |
| [TaxSettings](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/taxsettings.html#taxsettings) | ✓ | `session.taxsettings.client(...)` | `boto3.client("taxsettings", ...)` |
| [Textract](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/textract.html#textract) | ✓ | `session.textract.client(...)` | `boto3.client("textract", ...)` |
| [TimestreamInfluxDB](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-influxdb.html#timestreaminfluxdb) | ✓ | `session.timestream_influxdb.client(...)` | `boto3.client("timestream-influxdb", ...)` |
| [TimestreamQuery](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-query.html#timestreamquery) | ✓ | `session.timestream_query.client(...)` | `boto3.client("timestream-query", ...)` |
| [TimestreamWrite](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-write.html#timestreamwrite) | ✓ | `session.timestream_write.client(...)` | `boto3.client("timestream-write", ...)` |
| [TelcoNetworkBuilder](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/tnb.html#telconetworkbuilder) | ✓ | `session.tnb.client(...)` | `boto3.client("tnb", ...)` |
| [TranscribeService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transcribe.html#transcribeservice) | ✓ | `session.transcribe.client(...)` | `boto3.client("transcribe", ...)` |
| [Transfer](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#transfer) | ✓ | `session.transfer.client(...)` | `boto3.client("transfer", ...)` |
| [Translate](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/translate.html#translate) | ✓ | `session.translate.client(...)` | `boto3.client("translate", ...)` |
| [TrustedAdvisorPublicAPI](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/trustedadvisor.html#trustedadvisorpublicapi) | ✓ | `session.trustedadvisor.client(...)` | `boto3.client("trustedadvisor", ...)` |
| [VerifiedPermissions](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/verifiedpermissions.html#verifiedpermissions) | ✓ | `session.verifiedpermissions.client(...)` | `boto3.client("verifiedpermissions", ...)` |
| [VoiceID](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/voice-id.html#voiceid) | ✓ | `session.voice_id.client(...)` | `boto3.client("voice-id", ...)` |
| [VPCLattice](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/vpc-lattice.html#vpclattice) | ✓ | `session.vpc_lattice.client(...)` | `boto3.client("vpc-lattice", ...)` |
| [WAF](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/waf.html#waf) | ✓ | `session.waf.client(...)` | `boto3.client("waf", ...)` |
| [WAFRegional](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/waf-regional.html#wafregional) | ✓ | `session.waf_regional.client(...)` | `boto3.client("waf-regional", ...)` |
| [WAFV2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wafv2.html#wafv2) | ✓ | `session.wafv2.client(...)` | `boto3.client("wafv2", ...)` |
| [WellArchitected](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wellarchitected.html#wellarchitected) | ✓ | `session.wellarchitected.client(...)` | `boto3.client("wellarchitected", ...)` |
| [ConnectWisdomService](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#connectwisdomservice) | ✓ | `session.wisdom.client(...)` | `boto3.client("wisdom", ...)` |
| [WorkDocs](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#workdocs) | ✓ | `session.workdocs.client(...)` | `boto3.client("workdocs", ...)` |
| [WorkMail](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmail.html#workmail) | ✓ | `session.workmail.client(...)` | `boto3.client("workmail", ...)` |
| [WorkMailMessageFlow](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workmailmessageflow.html#workmailmessageflow) | ✓ | `session.workmailmessageflow.client(...)` | `boto3.client("workmailmessageflow", ...)` |
| [WorkSpaces](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces.html#workspaces) | ✓ | `session.workspaces.client(...)` | `boto3.client("workspaces", ...)` |
| [WorkSpacesThinClient](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-thin-client.html#workspacesthinclient) | ✓ | `session.workspaces_thin_client.client(...)` | `boto3.client("workspaces-thin-client", ...)` |
| [WorkSpacesWeb](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#workspacesweb) | ✓ | `session.workspaces_web.client(...)` | `boto3.client("workspaces-web", ...)` |
| [XRay](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/xray.html#xray) | ✓ | `session.xray.client(...)` | `boto3.client("xray", ...)` |
